==> healthrian_visualization_support-1.1.7.tar.gz: lib/src/widgets/cardio_click/lead_state_cardioclick.dart <==
// ignore_for_file: public_member_api_docs

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';
import 'package:healthrian_common_support/healthrian_common_support.dart';
import 'package:healthrian_visualization_support/healthrian_visualization_support.dart';

part 'lead_state_cardioclick.g.dart';

@CopyWith()
class LeadStateCardioClick extends StatelessWidget {
  const LeadStateCardioClick({
    super.key,
    this.width = 300,
    this.height = 150,
    this.onLoadingWidget,
    this.wrapperWidget,
  });

  final double width;
  final double height;
  final Widget? onLoadingWidget;

  final Widget Function(List<bool>)? wrapperWidget;

  @override
  Widget build(BuildContext context) {
    final f = wrapperWidget ??
        (List<bool> leadstate) {
          return CustomPaint(
            size: Size(width, height),
            painter: DrawLead(leadstate: leadstate),
          );
        };

    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder<LeadState?>(
          stream: BLEManager().manageCardioClick.streams.leadStateStream,
          builder: (context, snapshot) {
            if (!snapshot.hasData) return onLoadingWidget ?? f([]);
            final leadstate = snapshot.data?.toList() ?? [];
            return f(leadstate);
          },
        );
      },
    );
  }
}

==> healthrian_visualization_support-1.1.20.tar.gz: lib/src/widgets/cardio_click/lead_state_cardioclick.dart <==
// ignore_for_file: public_member_api_docs

import 'package:copy_with_extension/copy_with_extension.dart';
import 'package:flutter/material.dart';
import 'package:flutter_mobx/flutter_mobx.dart';
import 'package:healthrian_ble_support/healthrian_ble_support.dart';
import 'package:healthrian_common_support/healthrian_common_support.dart';
import 'package:healthrian_visualization_support/healthrian_visualization_support.dart';

part 'lead_state_cardioclick.g.dart';

@CopyWith()
class LeadStateCardioClick extends StatelessWidget {
  const LeadStateCardioClick({
    super.key,
    this.width = 300,
    this.height = 150,
    this.onLoadingWidget,
    this.wrapperWidget,
  });

  final double width;
  final double height;
  final Widget? onLoadingWidget;

  final Widget Function(List<bool>)? wrapperWidget;

  @override
  Widget build(BuildContext context) {
    final f = wrapperWidget ??
        (List<bool> leadstate) {
          return CustomPaint(
            size: Size(width, height),
            painter: DrawLead(leadstate: leadstate),
          );
        };

    return Observer(
      key: UniqueKey(),
      builder: (context) {
        return StreamBuilder<LeadState?>(
          stream: BLEManager().manageCardioClick.streams.leadStateStreamEcg,
          builder: (context, snapshot) {
            if (!snapshot.hasData) return onLoadingWidget ?? f([]);
            final leadstate = snapshot.data?.toList() ?? [];
            return f(leadstate);
          },
        );
      },
    );
  }
}
